@@ -26,7 +26,7 @@
 #![doc = include_str!("./bin/nixel.rs")]
 //! ```
 pub mod ast;
-// pub mod cst;
+pub mod cst;
 pub mod deps;
 pub mod grammar;
 pub mod lexer;
